@@ -76,26 +76,31 @@ link_files = {
 # Be strict about any broken references:
 nitpicky = True
 
+# Include Python intersphinx mapping to prevent failures
+# jaraco/skeleton#51
+extensions += ['sphinx.ext.intersphinx']
 intersphinx_mapping = {
-    'pypa-build': ('https://pypa-build.readthedocs.io/en/latest/', None)
+    'python': ('https://docs.python.org/3', None),
 }
 
+intersphinx_mapping.update({
+    'pypa-build': ('https://pypa-build.readthedocs.io/en/latest/', None)
+})
+
 # Add support for linking usernames
 github_url = 'https://github.com'
 github_sponsors_url = f'{github_url}/sponsors'
 extlinks = {
     'user': (f'{github_sponsors_url}/%s', '@'),  # noqa: WPS323
 }
-extensions += ['sphinx.ext.extlinks', 'sphinx.ext.intersphinx']
+extensions += ['sphinx.ext.extlinks']
 
 # Ref: https://github.com/python-attrs/attrs/pull/571/files\
 #      #diff-85987f48f1258d9ee486e3191495582dR82
 default_role = 'any'
 
-# Custom sidebar templates, maps document names to template names.
-html_theme = 'alabaster'
-templates_path = ['_templates']
-html_sidebars = {'index': ['tidelift-sidebar.html']}
+# HTML theme
+html_theme = 'furo'
 
 # Add support for inline tabs
 extensions += ['sphinx_inline_tabs']
@@ -150,3 +155,5 @@ extensions += ['sphinxcontrib.towncrier']
 towncrier_draft_working_directory = '..'
 # Avoid an empty section for unpublished changes.
 towncrier_draft_include_empty = False
+
+extensions += ['jaraco.tidelift']
